@@ -1,5 +1,5 @@
 /* This file is part of GNU Pies.
-   Copyright (C) 2016-2020 Sergey Poznyakoff
+   Copyright (C) 2016-2022 Sergey Poznyakoff
 
    GNU Pies is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -218,8 +218,10 @@ argvcmp (char **a, char **b)
 {
   size_t i;
 
-  if (!a != !b)
-    return 1;
+  if (!a)
+    return !!b;
+  else if (!b)
+    return !!a;
 
   for (i = 0; a[i]; i++)
     if (!b[i] || strcmp (b[i], a[i]))
@@ -271,8 +273,10 @@ component_match (struct component *comp, struct component *ref)
   EQ (mode);
   FN (tag, safe_strcmp);
   FN (program, safe_strcmp);
+  FN (command, safe_strcmp);
   EQ (argc);
   FN (argv, argvcmp);
+  FN (envop, envop_cmp);
   FN (dir, safe_strcmp);
   FN (prereq, grecs_list_compare);
   FN (depend, grecs_list_compare);
@@ -280,6 +284,7 @@ component_match (struct component *comp, struct component *ref)
   EQ (max_instances);
   FN (rmfile, safe_strcmp);
   FNP (privs, pies_privs_cmp);
+  EQ (umask);
   FN (limits, limits_cmp);
   FN (runlevels, safe_strcmp);
   EQ (max_rate);
