@@ -1,5 +1,5 @@
 /* This file is part of GNU Pies.
-   Copyright (C) 2008-2021 Sergey Poznyakoff
+   Copyright (C) 2008-2022 Sergey Poznyakoff
 
    GNU Pies is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -626,6 +626,7 @@ parse_legacy_env (char **argv, envop_t **envop)
 	      else
 		{
 		  msize = len + vlen + 6;
+		  mem = grecs_malloc (msize);
 		  snprintf (mem, msize, "${%s:-}%s", name, value);
 		}
 	      value = mem;
@@ -648,6 +649,7 @@ parse_legacy_env (char **argv, envop_t **envop)
 	      else
 		{
 		  msize = len + vlen + 6;
+		  mem = grecs_malloc (msize);
 		  snprintf (mem, msize, "%s${%s:-}", value, name);
 		}
 	      value = mem;
@@ -1794,20 +1796,8 @@ struct grecs_keyword pies_keywords[] = {
 void
 config_init (void)
 {
-  struct wordsplit ws;
-  
   grecs_preprocessor = DEFAULT_PREPROCESSOR;
   
-  ws.ws_delim = ":";
-  if (wordsplit (DEFAULT_INCLUDE_PATH, &ws,
-		 WRDSF_DELIM |
-		 WRDSF_ENOMEMABRT |
-		 WRDSF_SHOWERR |
-		 WRDSF_NOCMD |
-		 WRDSF_NOVAR) == 0)
-    grecs_include_path_setup_v (ws.ws_wordv);
-  wordsplit_free (&ws);
-
   grecs_log_to_stderr = log_to_stderr_only;
   pies_identity_mechanism_register (&system_identity_mechanism);
 #ifdef WITH_PAM
@@ -2485,7 +2475,7 @@ main (int argc, char **argv)
 	  struct config_file *file = ep->data;
 
 	  if (file->syntax == &config_syntax_tab[CONF_PIES]
-	      && grecs_preproc_run (file->name, grecs_preprocessor))
+	      && grecs_preprocess (file->name, 0))
 	    exit (EX_CONFIG);
 	}
       exit (0);
