@@ -1,5 +1,5 @@
 /* This file is part of GNU Pies.
-   Copyright (C) 2015-2020 Sergey Poznyakoff
+   Copyright (C) 2015-2022 Sergey Poznyakoff
 
    GNU Pies is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -136,9 +136,7 @@ parse_config (void)
 {
   char *file_name;
   struct grecs_node *tree;
-  
-  grecs_include_path_setup (DEFAULT_VERSION_INCLUDE_DIR,
-			    DEFAULT_INCLUDE_DIR, NULL);
+
   grecs_log_to_stderr = 1;
   grecs_preprocessor = pp_command_line ();
   grecs_sockaddr_hints = &hints;
@@ -153,7 +151,7 @@ parse_config (void)
   if (file_name)
     {
       if (preprocess_only)
-	exit (grecs_preproc_run (file_name, grecs_preprocessor)
+	exit (grecs_preprocess (file_name, 0)
 	      ? EX_CONFIG : EX_OK);
       if (verbose)
 	printf (_("%s: reading configuration from %s\n"),
@@ -168,7 +166,7 @@ parse_config (void)
 		program_name, file_name);
     }
 
-  if (!client.url)
+  if (!client.url && !default_url)
     {
       /* Try local instance configuration */
       file_name = mkfilename (SYSCONFDIR, instance, ".conf");
@@ -180,7 +178,7 @@ parse_config (void)
 	    printf (_("%s: reading configuration from %s\n"),
 		    program_name, file_name);
 	  if (preprocess_only)
-	    exit (grecs_preproc_run (file_name, grecs_preprocessor)
+	    exit (grecs_preprocess (file_name, 0)
 		  ? EX_CONFIG : EX_OK);
 	  tree = grecs_parse (file_name);
 	  node = grecs_find_node (tree, "/control/socket");
@@ -2322,6 +2320,7 @@ main (int argc, char **argv)
   textdomain (PACKAGE);
 #endif
   grecs_print_diag_fun = piesctl_diag;
+  grecs_preprocessor = DEFAULT_PREPROCESSOR;
 
   proginfo.print_help_hook = command_help;
   parse_options (argc, argv, &i);
